@@ -1,24 +1,26 @@
-/*
- * HighContrast GTK+ rendering engine for Gnome-Themes.
- *
- * Copyright 2003 Sun Microsystems Inc.
+/* High Contrast - a cairo based GTK+ engine
+ * Copyright (C) 2003 Sun Microsystems Inc.
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
  */
 
+
 #include "hc_gtk2_engine.h"
 #include "hc_gtk2_support.h"
 #include "hc_gtk2_drawing.h"
@@ -342,7 +344,7 @@ hc_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_WIDGET(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
 	              (pointer_y >= GTK_WIDGET(child->data)->allocation.y) &&
@@ -390,13 +392,13 @@ hc_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
                   if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
-                         GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
+                         gtk_widget_get_visible (GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
-                         GTK_WIDGET_VISIBLE(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
+                         gtk_widget_get_visible (GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
 	          {
                     gtk_widget_set_state (GTK_WIDGET(child->data), GTK_STATE_NORMAL);
                   }
@@ -427,25 +429,25 @@ hc_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
       if (!g_object_get_data(G_OBJECT(widget), "HC_MENU_SHELL_HACK_SET"))
       {
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
-                                             (GtkSignalFunc)hc_gtk2_engine_hack_menu_shell_motion,
+                                             (GCallback)hc_gtk2_engine_hack_menu_shell_motion,
                                              NULL);
                                   
         g_object_set_data(G_OBJECT(widget), "HC_MENU_SHELL_MOTION_ID", (gpointer)id);
         
         id = g_signal_connect(G_OBJECT(widget), "leave-notify-event",
-                                             (GtkSignalFunc)hc_gtk2_engine_hack_menu_shell_leave,
+                                             (GCallback)hc_gtk2_engine_hack_menu_shell_leave,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "HC_MENU_SHELL_LEAVE_ID", (gpointer)id);
                                              
         id = g_signal_connect(G_OBJECT(widget), "destroy-event",
-                                             (GtkSignalFunc)hc_gtk2_engine_hack_menu_shell_destroy,
+                                             (GCallback)hc_gtk2_engine_hack_menu_shell_destroy,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "HC_MENU_SHELL_DESTROY_ID", (gpointer)id);
  
         g_object_set_data(G_OBJECT(widget), "HC_MENU_SHELL_HACK_SET", (gpointer)1);
         
         id = g_signal_connect(G_OBJECT(widget), "style-set",
-                                             (GtkSignalFunc)hc_gtk2_engine_hack_menu_shell_style_set,
+                                             (GCallback)hc_gtk2_engine_hack_menu_shell_style_set,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "HC_MENU_SHELL_STYLE_SET_ID", (gpointer)id);
       }
