@@ -35,7 +35,6 @@ typedef enum {
 	WIDGET_PROGRESS_BAR,
 	WIDGET_MENUBAR,
 	WIDGET_MENUBAR_ITEM,
-	WIDGET_OPTION_MENU,
 	WIDGET_TOOLBAR,
 	WIDGET_DEFAULT_BUTTON
 } WidgetType;
@@ -60,7 +59,6 @@ widget_type_get_type (void)
 			{ WIDGET_PROGRESS_BAR, "WIDGET_PROGRESS_BAR", "GtkProgessBar" },
 			{ WIDGET_MENUBAR, "WIDGET_MENUBAR", "GtkMenubar" },
 			{ WIDGET_MENUBAR_ITEM, "WIDGET_MENUBAR_ITEM", "GtkMenubar-item" },
-			{ WIDGET_OPTION_MENU, "WIDGET_OPTION_MENU", "GtkOptionMenu" },
 			{ WIDGET_TOOLBAR, "WIDGET_TOOLBAR", "GtkToolbar" },
 			{ WIDGET_DEFAULT_BUTTON, "WIDGET_DEFAULT_BUTTON", "GtkButton-has-default" },
 			{ 0, NULL, NULL }
@@ -160,7 +158,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		ARROW_ALL,
 		FILL_ALL,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -186,7 +184,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		EXPANDER_ALL,
 		GDK_WINDOW_EDGE_SOUTH
@@ -199,7 +197,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		ORIENTATION_ALL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -212,7 +210,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		EDGE_ALL
@@ -225,7 +223,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -238,7 +236,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -251,7 +249,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -270,7 +268,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -283,7 +281,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -296,7 +294,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -309,7 +307,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -322,7 +320,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -335,7 +333,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -348,7 +346,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -361,7 +359,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -374,33 +372,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
-		GTK_ORIENTATION_HORIZONTAL,
-		GTK_EXPANDER_EXPANDED,
-		GDK_WINDOW_EDGE_SOUTH
-	},
-	{
-		FUNCTION_BOX,
-		WIDGET_OPTION_MENU,
-		"NULL:optionmenu",
-		STATE_ALL,
-		SHADOW_ALL,
-		GTK_ARROW_UP,
-		TRUE,
-		GTK_SIDE_TOP,
-		GTK_ORIENTATION_HORIZONTAL,
-		GTK_EXPANDER_EXPANDED,
-		GDK_WINDOW_EDGE_SOUTH
-	},
-	{
-		FUNCTION_BOX,
-		WIDGET_OPTION_MENU,
-		"NULL:optionmenu",
-		STATE_ALL,
-		SHADOW_ALL,
-		GTK_ARROW_UP,
-		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -413,7 +385,7 @@ static Test tests[] = {
 		SHADOW_ALL,
 		GTK_ARROW_UP,
 		TRUE,
-		GTK_SIDE_TOP,
+		GTK_POS_TOP,
 		GTK_ORIENTATION_HORIZONTAL,
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
@@ -651,7 +623,6 @@ create_testwidgets ()
 	widgets[WIDGET_MENUBAR] = gtk_menu_bar_new ();
 	widgets[WIDGET_MENUBAR_ITEM] = gtk_menu_item_new_with_label ("blah");
 	gtk_menu_shell_append (GTK_MENU_SHELL (widgets[WIDGET_MENUBAR]), widgets[WIDGET_MENUBAR_ITEM]);
-	widgets[WIDGET_OPTION_MENU] = gtk_option_menu_new ();
 	widgets[WIDGET_TOOLBAR] = gtk_toolbar_new ();
 	widgets[WIDGET_DEFAULT_BUTTON] = gtk_button_new_with_label ("blah");
 	/* nasty but *shrug* */
